Tkinter app that acts as a GUI for IndieK software.

============
Installation
============

To install from PyPI: ``pip install indiek-gui``

To develop, use the [dev] dependency specification, e.g.:
``pip install indiek-gui[dev]``

Or from the cloned repo's top-level in editable mode:
``pip install -e .[dev]``

==========
Quickstart
==========
Call ``indiek-gui`` from your terminal to launch the GUI.

..  code-block:: bash

    indiek-gui

=====
Tests
=====
To run the full test suite, type the following from the top level of this repo:
``pytest``
